# -*- coding: utf-8 -*-

from makiki.executor import FunctionExecutor
from makiki.http import (
    generate_http_api,
    simple_http_wrapper,
    TimeoutWrapper
)

from .urls import user_apis


func_executor = FunctionExecutor(http_wrapper=simple_http_wrapper)
api = generate_http_api(
    module_name=__name__,
    user_apis=user_apis,
    executor=func_executor,
)

web_wsgi = TimeoutWrapper(__hug_wsgi__, timeout=15)  # noqa
